#
# spec file for package cacti-spine
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2024 Andreas Stieger <Andreas.Stieger@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{!?make_build: %define make_build make %{?_smp_mflags}}
Name:           cacti-spine
Version:        1.2.27
Release:        1.1
Summary:        Threaded poller for Cacti written in C
License:        LGPL-2.1-or-later
URL:            https://www.cacti.net/spine_info.php
Source:         https://www.cacti.net/downloads/spine/%{name}-%{version}.tar.gz
BuildRequires:  help2man
BuildRequires:  libtool
BuildRequires:  mysql-devel
BuildRequires:  net-snmp-devel
BuildRequires:  openssl-devel
Requires:       cacti = %{version}
Requires:       rrdtool

%description
Spine is a supplemental poller for Cacti that makes use of pthreads to achieve
excellent performance.

%prep
%autosetup -p1

%build
./bootstrap
%configure
%make_build

%install
%make_install

%files
%license LICENSE
%doc CHANGELOG README.md
%config %{_sysconfdir}/spine.conf.dist
%{_bindir}/spine
%{_mandir}/man1/spine*

%changelog
* Tue May 14 2024 Andreas Stieger <andreas.stieger@gmx.de>
- cacti-spine 1.2.27:
  * Restore AES Support
* Sun Dec 24 2023 Andreas Stieger <andreas.stieger@gmx.de>
- cacti-spine 1.2.26:
  * Fix: Errors when uptime OID is not present
  * Fix: MySQL reconnect option is depreciated
  * Fix: Spine does not check a host with no poller items
  * Fix: Poller may report the wrong number of devices polled
  * Feature: Allow users to override the threads setting at the command line
  * Feature: Allow spine to run in ping-only mode
* Wed Sep  6 2023 Andreas Stieger <andreas.stieger@gmx.de>
- cacti-spine 1.2.25:
  * Spine should see if script to be executed is executable
  * Enhance number recognition
  * When polling devices, sort by larger number of items first
  * Log format may be corrupted when timeout occurs
  * Compile warning appears due to GCC flag on RHEL7/RHEL8
  * Downed device detection only checks one of the two uptime OIDs
  * Compile error appears due to execinfo.h on FreeBSD
  * Bootstrap shell script contains some PHP cruft
  * Padding is not always removed from the start of non-numeric
    strings
  * Improve SNMP result handling for non-numeric results
  * Further improve SNMP result handling for non-numeric results
  * Remove check for the max_oids column which has been present
    since Cacti v1.0
  * Minimize Sorting when fetching poller records for maximum
    performance
  * Spine should see if script to be executed is executable
* Mon Feb 27 2023 Andreas Stieger <andreas.stieger@gmx.de>
- cacti-spine 1.2.24:
  * Fix segfault when ignoring older OIDs
* Mon Jan  2 2023 Andreas Stieger <andreas.stieger@gmx.de>
- cacti-spine 1.2.23:
  * Fix unexpected reindexing when using uptime as the reindex
    method
  * Spine should prevent the script server from connecting to remote
    when offline
  * Improve Script Server Timeout Logging
  * Add SQL_NO_CACHE to Spine Queries
* Sun Oct  2 2022 Andreas Stieger <andreas.stieger@gmx.de>
- cacti-spine 1.2.22, delivering a number of bug fixes:
  * When polling time is exceed, spine does not always exit as expected
  * Spine logging at `-V 5` includes an extra line feed
  * Incorrect SNMP responses can cause spine to crash
  * Properly handle devices that timeout responding to the Extended Uptime
  * MariaDB can cause spine to abort prematurely despite error handling
  * Spine should log the error time when exiting via signal
* Sun May 29 2022 Andreas Stieger <andreas.stieger@gmx.de>
- cacti-spine 1.2.21:
  * Disable DES if Net-SNMP doesn't have it
* Fri Apr 22 2022 Andreas Stieger <andreas.stieger@gmx.de>
- cacti-spine 1.2.20:
  * Add support for newer versions of MySQL/MariaDB
  * When checking for uptime of device, don't assume a non-response
    is always fatal
  * Fix description and command trunctation issues
  * Improve spine performance when only one snmp agent port is in
    use
* Sat Nov  6 2021 Andreas Stieger <andreas.stieger@gmx.de>
- cacti-spine 1.2.19:
  * Fix 1ssues with polling loop may skip some datasources
  * Fix ping no longer works due to hostname changes
  * Fix RRD steps are not always calculated correctly
  * Fix unable to build when DES no longer supported
  * Fix IPv6 devices are not properly parsed
  * Reduce a number of compiler warnings
  * Fix compiler warnings due to lack of return in thread_mutex_trylock
  * Fix Spine will not look at non-timetics uptime when sysUpTimeInstance overflows
  * Improve performance of Cacti poller on heavily loaded systems
- drop cacti-spine-1.2.18-Fix-non-void-return.patch, upstream
* Sat Aug 21 2021 Andreas Stieger <andreas.stieger@gmx.de>
- cacti-spine 1.2.18:
  * Fix missing time parameter on FROM_UNIXTIME function
- add cacti-spine-1.2.18-Fix-non-void-return.patch to fix the same
* Wed May  5 2021 Andreas Stieger <andreas.stieger@gmx.de>
- cacti-spine 1.2.17:
  * Avoid triggering DDos detection in firewalls on large systems
  * Use mysql reconnect option properly
  * Fix possible creashes in various operations
  * Fix remote data collectors pushing too much data to main when
    performing diagnostics
  * Make spine more responsive when remote connection is down
  * Fix various MySQL issues
  * Make spine immune to DST changes
* Mon Dec  7 2020 Andreas Stieger <andreas.stieger@gmx.de>
- cacti-spine 1.2.16:
  * Some developer debug log messages falsely labeled as WARNINGS
  * Remove the need of the dos2unix program
  * Fix Spine experiencing MySQL socket error 2002 under load
  * Under heavy load MySQL/MariaDB return 2006 and 2013 errors on query
  * Add backtrace output to stderr for signals
  * Add Data Source turnaround time to debug output
* Wed Nov 11 2020 Andreas Stieger <andreas.stieger@gmx.de>
- cacti-spine 1.2.15:
  * Special characters may not always be ignored properly
* Mon Aug  3 2020 Andreas Stieger <andreas.stieger@gmx.de>
- cacti-spine 1.2.14:
  * fix spine not updating rrd_next_step
* Tue Jul 14 2020 Andreas Stieger <andreas.stieger@gmx.de>
- cacti-spine 1.2.13:
  * works with cacti 1.2.13
* Thu May  7 2020 Andreas Stieger <andreas.stieger@gmx.de>
- cacti-spine 1.2.12:
  * Failed host lookup causes spine to crash
* Sat Apr 11 2020 Andreas Stieger <andreas.stieger@gmx.de>
- cacti-spine 1.2.11:
  * fix warnings due to 'Recache Event Detected for Device'
  * Fix database, network and polling errors
* Sat Feb 15 2020 Andreas Stieger <andreas.stieger@gmx.de>
- cacti-spine 1.2.9:
  * works with cacti 1.2.9
  * Improve logging of snmp multiple OID get function
  * PCOMMAND Device[XXXX] WARNING: Recache Event Detected for Device
  * Segmentation Fault triggered by a lot of errors
  * Replace function gethostbyname with thread safe getaddrinfo
  * removed strip_alpha for "Wrong-Type" SNMP-Answer
* Sun Feb  2 2020 Andreas Stieger <andreas.stieger@gmx.de>
- cacti-spine 1.2.8:
  * works with cacti 1.2.8
* Thu Oct 17 2019 Richard Brown <rbrown@suse.com>
- Remove obsolete Groups tag (fate#326485)
* Mon Sep 30 2019 David Liedke <liedke@rz.uni-mannheim.de>
-Update to version 1.2.7
  - issue#113: spine1.2.6 couldn't open directory `m4'
* Mon Sep  2 2019 David Liedke <liedke@rz.uni-mannheim.de>
-Update to version 1.2.6
  - issue#101: MySQL 8 has retired 'my_bool' type
  - issue#104: Spine should report which threads are outstanding
  - issue#105: Spine should include 'Process[<id>]' in standard logging
  - issue#107: Log Buffer is too small to handle some output
  - issue#108: Once an SNMP timeout is reached, snmp_get does not honor
    include_host
  - issue#109: Initial declarations inside for loop cause compile errors
  - issue#110: When compiling, 'directive output may be truncated'
    messages can appear
  - issue#112: INSTALL instructions have typo in bootstrap command
* Tue Jul 16 2019 David Liedke <liedke@rz.uni-mannheim.de>
-Update to version 1.2.5
  - issue: Improve detection of MySQL vs. MariaDB client library requirement
  - issue#98: Checking type in poller.c causes compiler error
* Thu Jun 13 2019 David Liedke <liedke@rz.uni-mannheim.de>
-Update to version 1.2.4
  * issue#92: Add Data Source ID to "Empty result' error messages
  * issue#94: Increase default 'results_buffer' size to 2048 and MySQL
    max buffer to 131072 bytes
* Mon Apr  1 2019 David Liedke <liedke@rz.uni-mannheim.de>
-Update to version 1.2.3
  * issue#76: Spine unhandled exception signal
  * issue: More recent versions of MariaDB require different client library
* Mon Feb 25 2019 David Liedke <liedke@rz.uni-mannheim.de>
-Update to version 1.2.2
  * feature: release to match Cacti release
* Mon Jan 21 2019 liedke@rz.uni-mannheim.de
-Update to version 1.2.1
  * feature: release to match Cacti release
* Thu Jan  3 2019 liedke@rz.uni-mannheim.de
- Update to version 1.2.0
  * feature: Allow threads to be set a Data Collector level
  * issue#50: make fails on Debian 7 attempting to locate clock_gettime
  * issue#53: Improved escaping when updating database records
  * issue#54: Spine should always log if ICMP fails
  * issue#58: When updating snmp_sysLocation, text can become truncated
  * issue#63: Automatically reduce device threads when number of data
    sources does not require it
* Mon Apr 16 2018 liedke@rz.uni-mannheim.de
- Update to version 1.1.38
  * feature: release to match Cacti release
* Mon Mar 26 2018 liedke@rz.uni-mannheim.de
- Update to version 1.1.37
  - issue: Extra long snmp_sysObjectID's generate SQL errors
* Mon Feb 26 2018 liedke@rz.uni-mannheim.de
- Update to version 1.1.36
  - issue#49: Re-Index update query failed due to lack of escaping
* Mon Feb 12 2018 liedke@rz.uni-mannheim.de
- Update to version 1.1.35
  - issue#48: Availability check none triggers snmp system check that
    causes device to be ignored
* Tue Feb  6 2018 liedke@rz.uni-mannheim.de
- Update to version 1.1.34
  * feature: release to match Cacti release
* Tue Jan 23 2018 liedke@rz.uni-mannheim.de
- Update to version 1.1.33
  * feature: release to match Cacti release
* Mon Jan 22 2018 liedke@rz.uni-mannheim.de
- Update to version 1.1.32
  * feature: release to match Cacti release
* Wed Jan 17 2018 liedke@rz.uni-mannheim.de
- Update to version 1.1.31
  - issue#15: Spine cause CPU usage up to 100%%
  - issue#32: Support noAuthNoPriv in Spine
  - issue#34: Re-introduce check for relocatable Net-SNMP and
    development files
  - issue#35: SNMP OID range checks cause some snmpget's to fail
  - issue#38: SNMP Ping timeouts not reported properly
  - issue#39: Spine should use same logging format as Cacti
  - issue#41: Spine cause CPU usage up to 100%%
  - issue#42: Boost table keeps populating with boost disabled
* Thu Jan  4 2018 liedke@rz.uni-mannheim.de
- Update to version 1.1.30
  * feature: release to match Cacti release
* Wed Dec 27 2017 liedke@rz.uni-mannheim.de
- Update to version 1.1.29
  * issue#39: Have spine match cacti_log function
* Mon Nov 20 2017 liedke@rz.uni-mannheim.de
- Update to version 1.1.28
  * feature: release to match Cacti release
* Mon Oct 23 2017 liedke@rz.uni-mannheim.de
- Update to version 1.1.27
  * feature: release to match Cacti release
* Mon Oct 16 2017 liedke@rz.uni-mannheim.de
- Update to version 1.1.26
  * feature: release to match Cacti release
- Update to version 1.1.25
  * feature: release to match Cacti release
* Mon Sep 18 2017 liedke@rz.uni-mannheim.de
- Update to version 1.1.24
  * feature: release to match Cacti release
* Tue Sep 12 2017 liedke@rz.uni-mannheim.de
- Update to version 1.1.23
  * feature: release to match Cacti release
- Update to version 1.1.22
  * feature: release to match Cacti release
* Tue Sep  5 2017 liedke@rz.uni-mannheim.de
- Update to version 1.1.21
  * feature: release to match Cacti release
- Update to version 1.1.20
  * issue#28: UDP and TCP ping issues
* Mon Aug 21 2017 liedke@rz.uni-mannheim.de
- Update to version 1.1.19
  * feature: release to match Cacti release
- Update to version 1.1.18
  * issue: Sort devices by polling time to allow long running
    devices to go first
* Tue Aug 15 2017 liedke@rz.uni-mannheim.de
- Update to version 1.1.17
  * issue: Increase logging level for POPEN timeouts
* Tue Aug  1 2017 liedke@rz.uni-mannheim.de
- Update to version 1.1.16
  * feature: release to match Cacti release
* Mon Jul 24 2017 liedke@rz.uni-mannheim.de
- Update to version 1.1.15
  * feature: release to match Cacti release
* Mon Jul 24 2017 liedke@rz.uni-mannheim.de
- Update to version 1.1.14
  * feature: release to match Cacti release
* Fri Jul 14 2017 liedke@rz.uni-mannheim.de
- Update to version 1.1.13
  * issue: Script timeout should start after semaphore releases
  * issue: Don't include line breaks in Syslog
* Wed Jul  5 2017 liedke@rz.uni-mannheim.de
- Update to version 1.1.12
  * feature: release to match Cacti release
- Update to version 1.1.11
  * feature: release to match Cacti release
* Mon Jun 12 2017 liedke@rz.uni-mannheim.de
- Update to version 1.1.10
  * feature: release to match Cacti release
* Mon Jun  5 2017 liedke@rz.uni-mannheim.de
- Update to version 1.1.9
  * feature: release to match Cacti release
- Update to version 1.1.8
  * issue#21: Errors when snmp_sysLocation contains a single quote
* Mon May 22 2017 liedke@rz.uni-mannheim.de
- Update to version 1.1.7
  * feature: release to match Cacti release
* Mon May  8 2017 liedke@rz.uni-mannheim.de
- Update to version 1.1.6
  * issue#15: Spine can cause high CPU utilization due to
    semaphore implementation
  * issue#11: Spine reports SNMP timeouts in some cases when
    gathering multiple OID in one request
* Wed Apr 26 2017 liedke@rz.uni-mannheim.de
- Update to version 1.1.5
  * feature: release to match Cacti release
* Mon Apr 24 2017 liedke@rz.uni-mannheim.de
- Update to version 1.1.4
  * feature: release to match Cacti release
* Sun Apr 16 2017 liedke@rz.uni-mannheim.de
- Update to version 1.1.3
  * feature: release to match Cacti release
* Mon Apr  3 2017 liedke@rz.uni-mannheim.de
- Update to version 1.1.2
  * issue#13: Spine does not compile with --enable-lcap
  * issue#16: Spine not handling debug devices correctly
* Tue Mar 28 2017 liedke@rz.uni-mannheim.de
- Update to version 1.1.1
  * feature: release to match Cacti release
* Tue Mar 21 2017 joop.boonen@opensuse.org
- Update to version 1.1.0
  * feature: release to match Cacti release
* Wed Mar 15 2017 liedke@rz.uni-mannheim.de
- Update to version 1.0.6
  * feature: release to match Cacti release
* Mon Mar 13 2017 liedke@rz.uni-mannheim.de
- Update to version 1.0.5
  * issue#7: remove database name not respected
* Tue Feb 28 2017 joop.boonen@opensuse.org
- Update to version 1.0.4
  * feature: release to match Cacti release
* Fri Feb 24 2017 joop.boonen@opensuse.org
- Update to version 1.0.3
  * issue#6: Spine accepts arbitrary polling modes
- Update to version 1.0.2
  * feature: release to match Cacti release
- Update to version 1.0.1
  * bug:With enough make jobs, help2man will fail if help2man is run before spine has been built
- Update to version 1.0.0
  * feature: Track per host polling time
  * feature: Collect System Mib Information
  * feature: Place collection timing into host table
  * feature: Support snmpContextEngineID
  * feature: Change all references of Host to Device
  * bug:0001415: spine does not handle log_perror
  * bug#0002220: spine/cacti patch to allow SNMP_polling decices' hostnames like user@host:port
  * bug#0002234: Wrong alphanumeric value got from Spine SNMP poller
  * bug#0002651: False Positive Down status with snmpv3
  * bug#0002674: Segmentation fault in Spine during polling host
* Mon May  9 2016 liedke@rz.uni-mannheim.de
- Update to version 0.8.8h
  * bug:0002659: wrong information about spine setup for icmps
  * bug: Removed requirement for building man page, deferred to 1.0
- Update to version 0.8.8g
  * bug:0002380: please build man page for spine
  * bug:0002610: Spine is trying to use mysql results after data
    being freed
  * bug:0002639: Spine does not respect snmp_retries from the
    database
  * bug:0002640: Spine crashes randomly while polling using
    multiple threads on one device
  * bug:0002549: Spine: hasCaps() always returns FALSE
  * bug:0002638: Spine: ping_udp() uses uninitialised socket timeout
  * bug:0002654: On RHEL 6.5, spine ./configure builds Makefile
    without crypto support
* Sun Nov  1 2015 p.drouand@gmail.com
- Update to version 0.8.8f
  * bug:0002604: cacti-spine, configure script ignores LDFLAGS in
    certain situations
- Changes from version 0.8.8e
  * bug#0002185: Multiple memory leaks found in spine
  * bug#0002398: Buffer overflow
  * bug#0002447: Building spine on Debian Jessie (testing) fails
  * bug#0002536: Spine segfaults when 18k+ hosts are to be pulled
  * bug#0002576: Call to a non-existent column of the database in poller.c
  * bug#0002578: spine doesn't compile on ubuntu 12.04
  * bug#0002585: Spine: buffer overflow in logging when
    RESULTS_BUFFER>LOGSIZE can SEGV
  * bug#0002588: Spine "is_numeric" incorrectly returns TRUE for some
    hexadecimal values
- Remove systemd buildrequires; unneeded
* Thu Dec 25 2014 p.drouand@gmail.com
- Update to version 0.8.8c
  + No changelog entry for version 0.8.8c
- Use download Url as source
* Mon Aug 12 2013 aldemir.akpinar@gmail.com
- New Version: 0.8.8b
* Mon Apr 30 2012 cfarrell@suse.com
- license update: LGPL-2.1+
  Use SPDX format for license strings (http://www.spdx.org/licenses)
* Mon Apr 30 2012 aldemir.akpinar@airties.com
- New Version: 0.8.8a
- Add source as bz2
* Mon Apr  9 2012 aldemir.akpinar@airties.com
- Version 0.8.8
* Wed Dec 14 2011 aldemir.akpinar@airties.com
- Upgrade to 0.8.7i
* Wed Oct  5 2011 aldemir.akpinar@airties.com
- Upgrade to new version.
* Mon Jun 13 2011 aldemir.akpinar@airties.com
- Changed Requires line to comply with the changes on cacti-PA
* Fri Jun 10 2011 aldemir.akpinar@airties.com
- Changed cactid name to spine and made it installable with cacti-PA
* Tue Jun 29 2010 boris@steki.net
- Updated to new version
- Many bugs fixed
  Changes can be found in /usr/share/doc/packages/cacti-cactid/Changelog
